@@ -41,7 +41,7 @@ from DHParser.parse import ParserError, Parser, Grammar, Forward, TKN, ZeroOrMor
 from DHParser import compile_source
 from DHParser.ebnf import get_ebnf_grammar, get_ebnf_transformer, get_ebnf_compiler, \
     parse_ebnf, DHPARSER_IMPORTS, compile_ebnf
-from DHParser.dsl import grammar_provider, create_parser
+from DHParser.dsl import grammar_provider, create_parser, raw_compileEBNF
 from DHParser.syntaxtree import Node, parse_sxpr
 from DHParser.stringview import StringView
 from DHParser.trace import set_tracer, trace_history, resume_notices_on
@@ -111,6 +111,16 @@ class TestParserClass:
 
 
 class TestInfiLoopsAndRecursion:
+    def test_very_simple(self):
+        minilang = """
+            term = term (`*`|`/`) factor | factor
+            factor = /[0-9]+/
+            """
+        parser = grammar_provider(minilang)()
+        snippet = "5*4*3"
+        st = parser(snippet)
+        assert not is_error(st.error_flag)
+
     def test_direct_left_recursion1(self):
         minilang = """@literalws = right
             expr = expr ("+"|"-") term | term
@@ -119,6 +129,7 @@ class TestInfiLoopsAndRecursion:
             """
         snippet = "9 + 8 + 7 + 6 + 5 + 3 * 4"
         parser = grammar_provider(minilang)()
+        # print(raw_compileEBNF(minilang).result)
         assert parser
         syntax_tree = parser(snippet)
         assert not is_error(syntax_tree.error_flag), str(syntax_tree.errors_sorted)
@@ -148,6 +159,7 @@ class TestInfiLoopsAndRecursion:
             Sum     = Expr { ('+' | '-') Expr }+
             Value   = /[0-9.]+/~ | '(' §Expr ')'
             """
+        # print(raw_compileEBNF(minilang).result)
         parser = grammar_provider(minilang)()
         snippet = "8 * 4"
         syntax_tree = parser(snippet)
@@ -394,7 +406,7 @@ class TestGrammar:
     """
     pyparser, messages, _ = compile_source(grammar, None, get_ebnf_grammar(),
                                            get_ebnf_transformer(), get_ebnf_compiler("PosTest"))
-    assert pyparser
+    assert pyparser, str(messages)
     assert not messages, str(messages)
 
     def test_pos_values_initialized(self):
